@@ -2,13 +2,13 @@
 ## All global variables in here are used all over the program
 ###########################################################################
 
-configfolder="/home/user/.SleepAnalyser/" #users home dir with ending /
+configFolder="/home/user/.SleepAnalyser/" #users home dir with ending /
 homedir="/home/user/"
-defaultlogfolder="/home/user/MyDocs/SleepAnalyser/" #users log dir with ending /
+defaultRecordFolder="/home/user/MyDocs/SleepAnalyser/" #users record dir with ending /
 ConfigFile="SleepAnalyser.conf"
 
-devconfigfolder="/home/gruinelli/Entwicklung/Maemo/Sleepanalyser/" #development PC
-devlogfolder="/home/gruinelli/Entwicklung/Maemo/Sleepanalyser/data/" #development PC
+developmentconfigFolder="/home/gruinelli/Entwicklung/Maemo/Sleepanalyser/" #development PC
+developmentRecordFolder="/home/gruinelli/Entwicklung/Maemo/Sleepanalyser/data/" #development PC
 
 dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the record files
 
@@ -47,8 +47,8 @@ Yscale_sleep=1
 Value_index=0
 Values_total=0
 
-arrLogFiles=[]
-arrLogFileIndex=0
+arrRecordFiles=[]
+arrRecordFilesIndex=0
 
 Trigger=14 #Trigger level for movement
 maxTrigger=100
@@ -56,9 +56,9 @@ maxTrigger=100
 demo=0
 debug=0
 
-logfilename=""
-logfile=""
-logfolder=""
+RecordFilename=""
+RecordFile=""
+RecordFolder=""
 LastRecord=""
 
 #ChangesInGraph=False
@@ -66,6 +66,8 @@ run=False
 QuickMode=False
 version="0"
 build="0"
+configFileVersion=1 #increase if parmeters have changed
+
 user=""
 app_path="./"
 #passed_time=0
@@ -74,10 +76,13 @@ DelayStartTime=10
 #DropIndexes=0
 last_beep=0
 #graphBlocks=0
+
+SwitchedModes=False
 OfflineMode=False
 PreviousMode="normal"
 SilentProfile=False
 PreviouseProfile="silent"
+
 DelayStart=0
 interval=0
 #GraphStart=0
@@ -107,9 +112,9 @@ Progress=""
 #arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen,        [0]*arrDataLen ,             [0]*arrDataLen]
 arrDataTemp=[0, 0, 0] #[0]=X, [1]=Y, [2]=Z
 arrDataIndex=0
-arrLogFiles=[]
-arrLogFilesIndex=0
-LogFileSelectedDate=""
+arrRecordFiles=[]
+arrRecordFilesIndex=0
+RecordFileSelectedDate=""
 
 #global QtGui
 
@@ -121,5 +126,6 @@ GraphBackground="#101010"
 #some colors are also defined in functions_record.py
 
 FilterScale=40
+limitMovement=250
 
 Animation=0
