@@ -19,7 +19,7 @@ APP_NAME = "SleepAnalyser"
 #LOCALE_DIR = data.app_path+"i18n/"
 LOCALE_DIR = data.app_path+"i18n/"
 
-print "LOCALE_DIR:", LOCALE_DIR
+#print "LOCALE_DIR:", LOCALE_DIR
 
 # Now we need to choose the language. We will provide a list, and gettext
 # will use the first translation available in the list
@@ -32,7 +32,7 @@ DEFAULT_LANGUAGES += ['en_US']
 
 # Try to get the languages from the default locale
 lc, encoding = locale.getdefaultlocale()
-print lc
+#print lc
 if lc:
  languages = [lc]
 
@@ -43,11 +43,13 @@ if lc:
 languages += DEFAULT_LANGUAGES
 mo_location = LOCALE_DIR
 
-print "languages:", languages
+#print "languages:", languages
 
 # Lets tell those details to gettext
 #  (nothing to change here for you)
 gettext.install (True)
+
+
 #gettext.bindtextdomain (APP_NAME,mo_location)
 #gettext.bindtextdomain(domain[, localedir])
 #gettext.find(domain[, localedir[, languages[, all]]])
