@@ -15,31 +15,37 @@ __ss_bool IsCompiled() {
     return r;
 }
 
-list<__ss_int> *sleep_filter(list<__ss_int> *ar, __ss_int l, list<__ss_int> *filter, __ss_int shift, __ss_int scale, __ss_int max) {
+list<__ss_int> *sleep_filter(list<__ss_int> *ar, __ss_int l, list<__ss_int> *filter, __ss_int shift, __ss_int scale, __ss_int max, __ss_int min, __ss_int limitMovement) {
     list<__ss_int> *ar_ret;
-    __ss_int __0, __1, __2, __3, __4, __5, i, len_filter, p, value;
+    __ss_int __0, __1, __2, __3, __4, __5, __6, __7, i, len_filter, p, value;
 
     len_filter = len(filter);
-    value = 1;
     ar_ret = ((new list<__ss_int>(1, 0)))->__mul__((l+len_filter));
 
     FAST_FOR(i,0,(l-1),1,0,1)
+        if ((ar->__getfast__(i)>limitMovement)) {
+            ar->__setitem__(i, limitMovement);
+        }
+    END_FOR
+
+
+    FAST_FOR(i,0,(l-1),1,2,3)
         value = ar->__getfast__(i);
 
-        FAST_FOR(p,0,(len_filter-1),1,2,3)
-            ar_ret->__setitem__(((i+p)-shift), (ar->__getfast__(((i+p)-shift))+(value*filter->__getfast__(p))));
+        FAST_FOR(p,0,(len_filter-1),1,4,5)
+            ar_ret->__setitem__(((i+p)-shift), (ar_ret->__getfast__(((i+p)-shift))+(value*filter->__getfast__(p))));
         END_FOR
 
     END_FOR
 
 
-    FAST_FOR(i,0,(l-1),1,4,5)
+    FAST_FOR(i,0,(l-1),1,6,7)
         value = __divs(ar_ret->__getfast__(i), (scale*100));
         if ((value>max)) {
             ar_ret->__setitem__(i, max);
         }
-        else if ((value<13)) {
-            ar_ret->__setitem__(i, 13);
+        else if ((value<min)) {
+            ar_ret->__setitem__(i, min);
         }
         else {
             ar_ret->__setitem__(i, value);
@@ -56,9 +62,9 @@ void __init() {
 
     if (__eq(__name__, const_0)) {
         IsCompiled();
-        arTest = (new list<__ss_int>(2, 1, 2));
+        arTest = (new list<__ss_int>(9, 1, 2, 3, 4, 5, 6, 7, 8, 9));
         arFiltertest = (new list<__ss_int>(3, 1, 2, 3));
-        sleep_filter(arTest, 1, arFiltertest, 1, 20, 120);
+        sleep_filter(arTest, 1, arFiltertest, 1, 20, 120, 13, 250);
     }
 }
 
@@ -92,8 +98,10 @@ PyObject *Global_mylib_sleep_filter(PyObject *self, PyObject *args, PyObject *kw
         __ss_int arg_3 = __ss_arg<__ss_int >("shift", 3, 0, NULL, args, kwargs);
         __ss_int arg_4 = __ss_arg<__ss_int >("scale", 4, 0, NULL, args, kwargs);
         __ss_int arg_5 = __ss_arg<__ss_int >("max", 5, 0, NULL, args, kwargs);
+        __ss_int arg_6 = __ss_arg<__ss_int >("min", 6, 0, NULL, args, kwargs);
+        __ss_int arg_7 = __ss_arg<__ss_int >("limitMovement", 7, 0, NULL, args, kwargs);
 
-        return __to_py(__mylib__::sleep_filter(arg_0, arg_1, arg_2, arg_3, arg_4, arg_5));
+        return __to_py(__mylib__::sleep_filter(arg_0, arg_1, arg_2, arg_3, arg_4, arg_5, arg_6, arg_7));
 
     } catch (Exception *e) {
         PyErr_SetString(__to_py(e), ((e->msg)?(e->msg->unit.c_str()):""));
