@@ -416,7 +416,7 @@ def MoveTrigger(direction):
 
 
 def About(ui):
-    QtGui.QMessageBox.about(ui, _("About")+" SleepAnalyser", _("Copyright 2010 by George Ruinelli with great support from the MAEMO community\n")+\
+    QtGui.QMessageBox.about(ui, _("About")+" SleepAnalyser", _("Copyright 2010 by George Ruinelli with great support from the MAEMO community")+"\n"+\
     _("Version:")+" "+str(data.version)+"-"+str(data.build)+"\n"+\
     _("Contact:")+" george@ruinelli.ch\n" +\
     _("Website:")+" http://www.ruinelli.ch/sleepanalyser/\n\n"+\
@@ -487,7 +487,6 @@ class frmStartWindow(QMainWindow):
         self.ui.bView.setText(_("View records"))
         self.ui.bCollecting.setText(_("Start recording only"))
         self.ui.bSetAlarm.setText(_("Set alarm and\nstart recording"))
-        self.ui.menuMenu.setTitle(_("Menu"))
         self.ui.actionAbout.setText(_("About"))
         self.ui.actionSettings.setText(_("Settings"))
         self.ui.actionHelp.setText(_("Help"))
@@ -1586,7 +1585,7 @@ class frmAdditionalInfoWindow(QMainWindow):
         self.ui = Ui_AdditionalInfoWindow()
         self.ui.setupUi(self)
 
-        self.setWindowTitle("SleepAnalyser ("+_("Record Info\'s)")+")")
+        self.setWindowTitle("SleepAnalyser ("+_("Record Info\'s")+")")
 
 
     ###########################################################################
@@ -1656,10 +1655,10 @@ class frmAdditionalInfoWindow(QMainWindow):
         txt=txt+"<hr>"
         txt=txt+"<b>"+_("Statistics:")+"</b><table>\n" + \
                 "<tr bgcolor=#DCDCDC><td><b>"+_("Time without<br>movement:")+" </b></td>   <td><b>"+_("Total:")+" </b></td>                                     <td><b>"+_("Maximum:")+"</b></td>                                    <td><b>"+_("Count:")+" </b></td>                     <td colspan=2><b>"+_("Time percent:")+"</b></td>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+_("&gt; 7 minutes:")+"</b></td>         <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[3][0]))+"</td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+_("&lt; 7 minutes:")+"</b></td>         <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[2][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[2][2]))+"</td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+_("&lt; 15 minutes:")+"</b></td>        <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[1][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[1][2]))+"</td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+_("&lt; 30 minutes:")+"</b></td>        <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[0][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[0][2]))+"</td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+"&gt; 7 "+_("minutes:")+"</b></td>         <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[3][0]))+"</td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 7 "+_("minutes:")+"</b></td>         <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[2][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[2][2]))+"</td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 15 "+_("minutes:")+"</b></td>        <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[1][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[1][2]))+"</td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 30 "+_("minutes:")+"</b></td>        <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[0][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[0][2]))+"</td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
               "</table>\n"
 
         txt=txt+"<hr>"
